Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Get ¶
type Get struct {
Sensor int `json:"sensor"`
Relay int `json:"relay"`
Timer int `json:"timer"`
UserSettings int `json:"userSettings"`
}
Get is a type for defining what information to request from DVI Energi webservice
type LoginGet ¶
type LoginGet struct {
Usermail string `json:"usermail"`
Userpassword string `json:"userpassword"`
Fabnr int `json:"fabnr"`
Get Get `json:"get"`
}
LoginGet is a type for defining the login at DVI Energi webservice
type LoginSet ¶
type LoginSet struct {
Usermail string `json:"usermail"`
Userpassword string `json:"userpassword"`
Fabnr int `json:"fabnr"`
Set map[string]int `json:"set"`
}
LoginSet is a type for defining the login at DVI Energi webservice for setting data
type Response ¶
type Response struct {
Access string `json:"Access"`
Fabnr int `json:"fabnr"`
Output ResponseOutput `json:"output"`
}
Response contains
type ResponseOutput ¶
type ResponseOutput struct {
Sensor ResponseOutputSensor `json:"sensor"`
Relay ResponseOutputRelay `json:"relay"`
Timer ResponseOutputTimer `json:"timer"`
UserSettings ResponseOutputUserSettings `json:"userSettings"`
}
ResponseOutput contains
type ResponseOutputRelay ¶
type ResponseOutputRelay struct {
Relay1 int `json:"Relay1,string"`
Relay2 int `json:"Relay2,string"`
Relay3 int `json:"Relay3,string"`
Relay4 int `json:"Relay4,string"`
Relay5 int `json:"Relay5,string"`
Relay6 int `json:"Relay6,string"`
Relay7 int `json:"Relay7,string"`
Relay8 int `json:"Relay8,string"`
Relay9 int `json:"Relay9,string"`
Relay10 int `json:"Relay10,string"`
Relay11 int `json:"Relay11,string"`
Relay12 int `json:"Relay12,string"`
Relay13 int `json:"Relay13,string"`
Relay14 int `json:"Relay14,string"`
}
ResponseOutputRelay contains relay data
type ResponseOutputSensor ¶
type ResponseOutputSensor struct {
SensorDate string `json:"Sensor.Date"`
CentralheatingForward float32 `json:"Centralheating.Forward,string"`
CentralheatingReturn float32 `json:"Centralheating.Return,string"`
StoragetankHotwater float32 `json:"Storagetank.Hotwater,string"`
Roomtemperature float32 `json:"Roomtemperature,string"`
StoragetankCentralheating float32 `json:"Storagetank.Centralheating,string"`
LVEvaporator1 float32 `json:"LV.Evaporator1,string"`
Outsidetemperature float32 `json:"Outsidetemperature,string"`
Energycatcher float32 `json:"Energycatcher,string"`
Solarheating float32 `json:"Solarheating,string"`
LVEvaporator2 float32 `json:"LV.Evaporator2,string"`
Highpressure float32 `json:"Highpressure,string"`
Lowpressure float32 `json:"Lowpressure,string"`
BrineReturn float32 `json:"Brine.Return,string"`
BrineForward float32 `json:"Brine.Forward,string"`
HeatmeterFlow float32 `json:"Heatmeter.Flow,string"`
HeatmeterKW float32 `json:"Heatmeter.kW,string"`
HeatmeterForward float32 `json:"Heatmeter.Forward,string"`
HeatmeterReturn float32 `json:"Heatmeter.Return,string"`
HeatmeterKWh float32 `json:"Heatmeter.kWh,string"`
PowermeterKW float32 `json:"Powermeter.kW,string"`
PowermeterKWh float32 `json:"Powermeter.kWh,string"`
}
ResponseOutputSensor contains sensor data
type ResponseOutputTimer ¶
type ResponseOutputTimer struct {
Compressor int `json:"compressor,string"`
Warmwater int `json:"warmwater,string"`
Pluswarm int `json:"pluswarm,string"`
Energicapture int `json:"energicapture,string"`
Sunwarm int `json:"sunwarm,string"`
Suntoearth int `json:"suntoearth,string"`
Cooling int `json:"cooling,string"`
}
ResponseOutputTimer contains strings, but currently data is integer - this may be changed to floating point numbers later
type ResponseOutputUserSettings ¶
type ResponseOutputUserSettings struct {
CentralheatCurve int `json:"Centralheat.Curve,string"`
CentralheatCurveTemp float32 `json:"Centralheat.CurveTemp,string"`
CentralheatState int `json:"Centralheat.State,string"`
CentralheatTemp int `json:"Centralheat.Temp,string"`
HotwaterClock int `json:"Hotwater.Clock,string"`
HotwaterState int `json:"Hotwater.State,string"`
HotwaterTemp int `json:"Hotwater.Temp,string"`
}
ResponseOutputUserSettings contains user settings
Click to show internal directories.
Click to hide internal directories.